@@ -153,8 +153,8 @@ fi
 
 echo "--- Launching {APP_NAME} ---"
 # Execute the application
-{PACKAGE_NAME} --version
-{PACKAGE_NAME} trend --default-idcs
+# {PACKAGE_NAME} --version
+# {PACKAGE_NAME} trend --default-idcs
 """
     try:
         upgrade_shortcut_file.write_text(upgrade_script_content, encoding='utf-8')
